TrinaGridLoadingLevel enum
When calling loading screen with TrinaGridStateManager.setShowLoading method Determines the level of loading.
grid makes the entire grid opaque and puts the loading indicator in the center. The user is in a state where no interaction is possible.
rows represents the LinearProgressIndicator at the top of the widget area that displays the rows. User can interact.
rowsBottomCircular represents the CircularProgressIndicator at the bottom of the widget that displays the rows. User can interact.
Values
- grid → const TrinaGridLoadingLevel
-
grid makes the entire grid opaque and puts the loading indicator in the center. The user is in a state where no interaction is possible.
- rows → const TrinaGridLoadingLevel
-
rows represents the LinearProgressIndicator at the top of the widget area that displays the rows. User can interact.
- rowsBottomCircular → const TrinaGridLoadingLevel
-
rowsBottomCircular represents the CircularProgressIndicator at the bottom of the widget that displays the rows. User can interact.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isGrid → bool
-
no setter
- isRows → bool
-
no setter
- isRowsBottomCircular → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TrinaGridLoadingLevel> - A constant List of the values in this enum, in order of their declaration.