TrinaGridMode enum
Values
- normal → const TrinaGridMode
-
Basic mode with most functions not limited, such as editing and selection.
- readOnly → const TrinaGridMode
-
Cell cannot be edited. To try to edit by force, it is possible as follows.
stateManager.changeCellValue( stateManager.currentCell!, 'test', force: true, ); - select → const TrinaGridMode
-
Mode for selecting one list from a specific list. Tap a row or press Enter to select the current row.
select Call the TrinaGrid.onSelected callback when the selected row is tapped. To select an unselected row, select the row and then tap once more. selectWithOneTap Same as select, but calls TrinaGrid.onSelected with one tap.
This mode is non-editable, but programmatically possible.
stateManager.changeCellValue( stateManager.currentRow!.cells['column_1']!, value, force: true, ); - selectWithOneTap → const TrinaGridMode
-
Mode for selecting one list from a specific list. Tap a row or press Enter to select the current row.
select Call the TrinaGrid.onSelected callback when the selected row is tapped. To select an unselected row, select the row and then tap once more. selectWithOneTap Same as select, but calls TrinaGrid.onSelected with one tap.
This mode is non-editable, but programmatically possible.
stateManager.changeCellValue( stateManager.currentRow!.cells['column_1']!, value, force: true, ); - multiSelect → const TrinaGridMode
-
Mode to select multiple rows. When a row is tapped, it is selected or deselected and the TrinaGrid.onSelected callback is called. TrinaGridOnSelectedEvent.selectedRows contains the selected rows. When a row is selected with keyboard shift + arrowDown/Up keys, the TrinaGrid.onSelected callback is called only when the Enter key is pressed. When the Escape key is pressed, the selected row is canceled and the TrinaGrid.onSelected callback is called with a TrinaGridOnSelectedEvent.selectedRows value of null.
- popup → const TrinaGridMode
-
This is a mode for popup type. It is used when calling a popup for filtering or column setting inside TrinaGrid, and it is not a mode for users.
If the user wants to run TrinaGrid as a popup, use TrinaGridPopup or
TrinaGridDualGridPopup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isEditableMode → bool
-
no setter
- isMultiSelect → bool
-
no setter
- isMultiSelectMode → bool
-
no setter
- isNormal → bool
-
no setter
- isPopup → bool
-
no setter
- isReadOnly → bool
-
no setter
- isSelect → bool
-
no setter
- isSelectMode → bool
-
no setter
- isSelectWithOneTap → bool
-
no setter
- isSingleSelectMode → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TrinaGridMode> - A constant List of the values in this enum, in order of their declaration.